==> cloudfoundry-client-2.4.0.BUILD-20170216.155240-40-sources.jar: org/cloudfoundry/client/v2/spacequotadefinitions/_ListSpaceQuotaDefinitionSpacesRequest.java <==
/*
 * Copyright 2013-2017 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.cloudfoundry.client.v2.spacequotadefinitions;

import com.fasterxml.jackson.annotation.JsonIgnore;
import org.cloudfoundry.Nullable;
import org.cloudfoundry.client.v2.InFilterParameter;
import org.cloudfoundry.client.v2.PaginatedRequest;
import org.immutables.value.Value;

import java.util.List;

/**
 * The request payload for the List all Spaces for the Space Quota Definition operation
 */
@Value.Immutable
abstract class _ListSpaceQuotaDefinitionSpacesRequest extends PaginatedRequest {

    /**
     * The application ids
     */
    @InFilterParameter("app_guid")
    @Nullable
    abstract List<String> getApplicationIds();

    /**
     * The developer ids
     */
    @InFilterParameter("developer_guid")
    @Nullable
    abstract List<String> getDeveloperIds();

    /**
     * The names
     */
    @InFilterParameter("name")
    @Nullable
    abstract List<String> getNames();

    /**
     * The organization ids
     */
    @InFilterParameter("organization_guid")
    @Nullable
    abstract List<String> getOrganizationIds();

    /**
     * The space quota definition id
     */
    @JsonIgnore
    abstract String getSpaceQuotaDefinitionId();

}

==> cloudfoundry-client-2.22.0.BUILD-20171107.200356-8-sources.jar: org/cloudfoundry/client/v2/spacequotadefinitions/_ListSpaceQuotaDefinitionSpacesRequest.java <==
/*
 * Copyright 2013-2017 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.cloudfoundry.client.v2.spacequotadefinitions;

import com.fasterxml.jackson.annotation.JsonIgnore;
import org.cloudfoundry.Nullable;
import org.cloudfoundry.client.v2.FilterParameter;
import org.cloudfoundry.client.v2.PaginatedRequest;
import org.immutables.value.Value;

import java.util.List;

/**
 * The request payload for the List all Spaces for the Space Quota Definition operation
 */
@Value.Immutable
abstract class _ListSpaceQuotaDefinitionSpacesRequest extends PaginatedRequest {

    /**
     * The application ids
     */
    @FilterParameter("app_guid")
    @Nullable
    abstract List<String> getApplicationIds();

    /**
     * The developer ids
     */
    @FilterParameter("developer_guid")
    @Nullable
    abstract List<String> getDeveloperIds();

    /**
     * The names
     */
    @FilterParameter("name")
    @Nullable
    abstract List<String> getNames();

    /**
     * The organization ids
     */
    @FilterParameter("organization_guid")
    @Nullable
    abstract List<String> getOrganizationIds();

    /**
     * The space quota definition id
     */
    @JsonIgnore
    abstract String getSpaceQuotaDefinitionId();

}
